@@ -48,13 +48,13 @@ sub test_cascade {
     ok( $cascade->{stats}{recompute} == 0, 'recompute stats - 1');
 
     is_deeply( $cascade->run('one_page_0'), [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10 ], '0th page from cache');
-    ok( $cascade->{stats}{recompute} == 2, 'recompute stats - 2');
+    cmp_ok( $cascade->{stats}{recompute}, '==', 2 );
 
     is_deeply( $cascade->run('one_page_1'), [ 11, 12, 13, 14, 15, 16, 17, 18, 19, 20 ], '1th page from cache');
-    ok( $cascade->{stats}{recompute} == 3, 'recompute stats - 3');
+    cmp_ok( $cascade->{stats}{recompute}, '==', 3 );
 
     is_deeply( $cascade->run('one_page_2'), [ 21, 22, 23, 24, 25, 26, 27, 28, 29, 30 ], '2th page from cache');
-    ok( $cascade->{stats}{recompute} == 4, 'recompute stats - 4');
+    cmp_ok( $cascade->{stats}{recompute}, '==', 4 );
 
     sleep 1;
 
@@ -62,13 +62,13 @@ sub test_cascade {
     $cascade->touch('big_array');
 
     is_deeply( $cascade->run('one_page_0'), [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10 ], '0th page from cache after touching');
-    cmp_ok( $cascade->{stats}{recompute}, '==', 5, 'recompute stats - 5');
+    cmp_ok( $cascade->{stats}{recompute}, '==', 5 );
 
     is_deeply( $cascade->run('one_page_1'), [ 11, 12, 13, 14, 15, 16, 17, 18, 19, 20 ], '1th page from cache after touching');
-    cmp_ok( $cascade->{stats}{recompute}, '==', 6, 'recompute stats - 6');
+    cmp_ok( $cascade->{stats}{recompute}, '==', 6 );
 
     is_deeply( $cascade->run('one_page_0'), [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10 ], '0th page from cache');
-    cmp_ok( $cascade->{stats}{recompute}, '==', 6, 'recompute stats - 7');
+    cmp_ok( $cascade->{stats}{recompute}, '==', 6 );
 }
 
 1;
